@@ -2,7 +2,7 @@
 """Darkweb Crawler Project
 =============================
 
-:mod:`darc` is designed as a swiss-knife for darkweb crawling.
+:mod:`darc` is designed as a swiss army knife for darkweb crawling.
 It integrates |requests|_ to collect HTTP request and response
 information, such as cookies, header fields, etc. It also bundles
 |selenium|_ to provide a fully rendered web page and screenshot
